@@ -8,7 +8,7 @@ import base64
 import os
 
 # initialize variables
-BASE_URL = 'https://2hsbtjui63.execute-api.us-west-1.amazonaws.com/sandbox/'
+BASE_URL = 'https://api.superpowered.ai/v1'
 
 def init(api_key_id: str, api_key_secret: str, verbose: bool = False):
     """
