@@ -4,6 +4,9 @@ import requests
 import time
 
 class Model:
+    """
+    The Model class is used to create, update, and delete models. It is also used to get information about a model and its instances.
+    """
     def __init__(self, model_spec: dict, supp_id: str = None, description: str = None, model_id: str = None):
         self.model_id = model_id
         self.model_spec = model_spec
@@ -64,15 +67,20 @@ class Model:
             instances[instance['id']] = inst
         return instances
 
-    # convenience method
     def create_instance(self, ai_name: str = "AI", additional_knowledge_bases: list = None):
+        """
+        creates a new instance of the model
+        """
         # TODO: add support for passing in knowledge bases by name instead of id
         instance_obj = ModelInstance(model_id=self.model_id, ai_name=ai_name, additional_knowledge_bases=additional_knowledge_bases)
         resp_body = instance_obj.create()
         return instance_obj
 
-    # convenience method for non-conversational use case - TODO: this is not an efficient way to do this
+    # TODO: this is not an efficient way to do this
     def run(self, prompt: str) -> str:
+        """
+        convenience method for non-conversational use case - creates a new instance, runs the prompt, and returns the response
+        """
         # create a new instance
         instance_obj = self.create_instance()
         instance_id = instance_obj.instance_id
@@ -88,6 +96,9 @@ class Model:
 
 
 class ModelInstance:
+    """
+    The ModelInstance class is used to create, update, and delete model instances. It is also used to get information about a model instance and its chat history.
+    """
     def __init__(self, ai_name: str, additional_knowledge_bases: list = None, model_id: str = None, supp_id: str = None, description: str = None, instance_id = None):
         self.ai_name = ai_name
         self.additional_knowledge_bases = additional_knowledge_bases # list of knowledge base ids
@@ -144,7 +155,10 @@ class ModelInstance:
         return resp['body']
 
     def respond(self, human_input):
-        # human input can a list of dicts with prefix and content or just a single dict of that form
+        """
+        given a human input, returns the model's response
+        - human_input can be a list of dicts with prefix and content as keys or just a single dict of that form
+        """
         url = BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}/get_response'
         payload = {
             'human_input': human_input
@@ -181,8 +195,10 @@ def model_spec_preprocessing(model_spec: dict):
         del model_spec["incantation_names"] 
     return model_spec
 
-# create_model() is a convenience function that creates a Model object and then calls its create() method
 def create_model(model_spec: dict = {}, verbose: bool = False):
+    """
+    create_model() is a convenience function that creates a Model object and then calls its create() method
+    """
     # check for the two required fields and add default values if they are not present
     if "model_title" not in model_spec:
         model_spec["model_title"] = "Untitled model " + str(int(time.time()))
@@ -194,8 +210,10 @@ def create_model(model_spec: dict = {}, verbose: bool = False):
     body_resp = model_obj.create()
     return model_obj
 
-# get_model() is a convenience function that returns a Model object for an existing model, given its title
 def get_model(model_title: str):
+    """
+    get_model() is a convenience function that returns a Model object for an existing model, given its title
+    """
     models = get_models()
     # create model name to id map - models is a dict of model objects keyed on model_id
     model_from_title = {}
@@ -212,8 +230,10 @@ def get_model(model_title: str):
     else:
         raise Exception('Model title not found: ' + model_title)
 
-# update_model() is a convenience function that updates an existing model, given its title and a new model_spec
 def update_model(model_title: str, new_model_spec: dict):
+    """
+    update_model() is a convenience function that updates an existing model, given its title and a new model_spec
+    """
     new_model_spec = model_spec_preprocessing(new_model_spec)
     model_obj = get_model(model_title)
     current_model_spec = model_obj.model_spec
@@ -225,8 +245,10 @@ def update_model(model_title: str, new_model_spec: dict):
     resp_body = model_obj.update()
     return model_obj
 
-# list_models() is a convenience function that returns a dictionary of all Model objects for an account
-def list_models(verbose=False):
+def list_models(verbose=True):
+    """
+    list_models() is a convenience function that returns a dictionary of all Model objects for an account
+    """
     models = get_models()
     if verbose:
         print ("\nModels:")
@@ -234,8 +256,10 @@ def list_models(verbose=False):
             print (f"id: {model_obj.model_id}\ntitle: {model_obj.title}\nmodel_spec: {model_obj.model_spec}\n")
     return models
 
-# list_instances() is a convenience function that returns a dictionary of ModelInstance objects for an existing model, given its title
 def list_instances(model_title: str, verbose=True):
+    """
+    list_instances() is a convenience function that returns a dictionary of ModelInstance objects for an existing model, given its title
+    """
     model = get_model(model_title)
     instances = model.get_instances()
     if verbose:
